import { TStyles } from '../styles/TStyles';
import { SerializableElement } from '../dom/to-serializable';
import { TStylesMerger } from '../styles/TStylesMerger';
import HTMLContentModel from '../model/HTMLContentModel';
import { HTMLElementModel } from '..';
export interface TNodeInit {
    /**
     * Opaque nodes will hold a reference to a serializable DOM node.
     */
    domNode?: SerializableElement;
    tagName?: string | null;
    contentModel: HTMLContentModel | null;
    elementModel: HTMLElementModel<string, HTMLContentModel> | null;
    attributes?: Record<string, string>;
    parentStyles: TStyles | null;
    styles?: TStyles | null;
    stylesMerger: TStylesMerger;
}
export declare type TNodeType = 'block' | 'phrasing' | 'text' | 'empty' | 'document';
export declare abstract class TNode implements TNodeInit {
    readonly type: TNodeType;
    readonly styles: TStyles;
    readonly attributes: Record<string, string>;
    readonly contentModel: HTMLContentModel | null;
    readonly elementModel: HTMLElementModel<string, HTMLContentModel> | null;
    readonly children: TNode[];
    readonly domNode?: SerializableElement;
    readonly tagName: string | null;
    readonly className: string | null;
    readonly id: string | null;
    readonly parentStyles: TStyles | null;
    readonly hasWhiteSpaceCollapsingEnabled: boolean;
    readonly stylesMerger: TStylesMerger;
    abstract readonly displayName: string;
    constructor(init: TNodeInit, type: TNodeType);
    abstract matchContentModel(contentModel: HTMLContentModel): boolean;
    bindChildren(children: TNode[]): void;
    cloneInitParams<T extends TNodeInit = TNodeInit>(partial?: Partial<T>): T;
    isCollapsibleLeft(): boolean;
    isCollapsibleRight(): boolean;
    isWhitespace(): boolean;
    isEmpty(): boolean;
    trimLeft(): void;
    trimRight(): void;
}
